@@ -40,7 +40,6 @@ def get_model(name):
 
   return r.json()
 
-
 def new_version(modelId):
   api_key = settings.get('api_key')
 
@@ -181,7 +180,6 @@ def deploy_scikit(scikit_model, name):
   print('> Scikit Model deployed')
   return version['number']
 
-
 def deploy_spacy(nlp_model, name):
   if(settings.get('api_key') == ''):
     print('No api key. Use inferrd.auth() first.')
@@ -225,20 +223,19 @@ def deploy_spacy(nlp_model, name):
   print('> Model deployed')
   return version['number']
   
-
 def get_request_history(apiKey, kwargs):
   print('Getting request')
 
 def call_model(serveKey, payload):
-  r = requests.post(api_host + '/infer/' + serveKey, data=json.dumps(payload), headers={'Content-Type': 'application/json'})
+  r = requests.post(api_host + '/infer/' + serveKey + '/predict', data=json.dumps(payload), headers={'Content-Type': 'application/json'})
   return r.json()
 
 def get(modelName):
   model = get_model(modelName)
-  serveKey = model.serveKey
+  serveKey = model['key']
 
   def infer(payload):
-    r = requests.post(api_host + '/infer/' + serveKey, data=json.dumps(payload), headers={'Content-Type': 'application/json'})
-  return r.json()
+    r = requests.post(api_host + '/infer/' + serveKey + '/predict', data=json.dumps(payload), headers={'Content-Type': 'application/json'})
+    return r.json()
 
   return infer
\ No newline at end of file
